@@ -23,10 +23,6 @@ from pathlib import Path
 import responses
 
 from ..iq.iq import IQ
-# from ..types.coordinates import Coordinates
-# from ..types.coordinateresults import CoordinateResults
-# from ..types.results_decoder import ResultsDecoder
-# from ..types.vulnerabilities import Vulnerabilities
 
 class TestIQ(unittest.TestCase):
   """TestIQ audits the call to IQ"""
@@ -136,3 +132,46 @@ class TestIQ(unittest.TestCase):
 
       self.func.poll_report(self.status_url)
     self.assertEqual(self.func.get_policy_action(), 'Warning')
+
+  @responses.activate
+  def test_call_poll_report_absolute_result_url(self):
+    """test_call_poll_report_relative_result_url mocks a call to IQ
+    and ensures an absolute report URL is returned,
+    and ensure that same absolute report URL is returned from get_absolute_report_url()"""
+    file = Path(__file__).parent / "iqresponse_absolute_report_url.json"
+    with open(file, "r") as stdin:
+      mock_json = json.loads(stdin.read())
+      responses.add(responses.GET,
+                    self.full_status_url,
+                    json=mock_json, status=200)
+
+      self.func.poll_report(self.status_url)
+    # pylint: disable=W0212
+    self.assertEqual(self.func._iq_url, 'http://afakeurlthatdoesnotexist.com:8081')
+    self.assertEqual(self.func.get_report_url(),
+                     'http://localhost:8070/ui/links/application/my-app/report/95c4c14e')
+    # ensure we use the IQ provided absolute URL
+    self.assertEqual(self.func.get_absolute_report_url(),
+                     'http://localhost:8070/ui/links/application/my-app/report/95c4c14e')
+
+  @responses.activate
+  def test_call_poll_report_relative_result_url(self):
+    """test_call_poll_report_relative_result_url mocks a call to IQ
+    and ensures a relative report URL is returned,
+    and ensure get_absolute_report_url() returns an absolute URL
+    built from the _iq_url and relative report URL"""
+    file = Path(__file__).parent / "iqresponse_relative_report_url.json"
+    with open(file, "r") as stdin:
+      mock_json = json.loads(stdin.read())
+      responses.add(responses.GET,
+                    self.full_status_url,
+                    json=mock_json, status=200)
+
+      self.func.poll_report(self.status_url)
+    # pylint: disable=W0212
+    self.assertEqual(self.func._iq_url, 'http://afakeurlthatdoesnotexist.com:8081')
+    self.assertEqual(self.func.get_report_url(),
+                     'ui/links/application/my-app/report/95c4c14e')
+    # build the absolute URL from the IQ Server base url
+    self.assertEqual(self.func.get_absolute_report_url(),
+        'http://afakeurlthatdoesnotexist.com:8081/ui/links/application/my-app/report/95c4c14e')
